==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.j(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
        a.item("StrokeThickness", "Number:double");
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.b(a);
        a.z("AssigningSeriesShapeStyleEventArgsBase", AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata, 'AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata');
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.k(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
        a.item("StrokeThickness", "Number:double");
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.b(a);
        a.ab("AssigningSeriesShapeStyleEventArgsBase", AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata, 'AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata');
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata };
